@@ -10,8 +10,7 @@ log = logging.getLogger(__name__)
 
 
 def _checksum_func(x):
-    ''' The result will be unsigned on Python 2/3. '''
-    return binascii.crc32(bytes(x)) & 0xFFFFFFFF
+    return binascii.crc32(bytes(x))
 
 
 class Checksum:
